@@ -1,15 +1,14 @@
 """ One-shot compression and decompression.
 """
 
-from wheezy.core.comp import BytesIO
-from wheezy.core.comp import GzipFile
+from wheezy.core.comp import BytesIO, GzipFile
 
 
 def compress(data, compresslevel=9):
     """ Compress data in one shot.
     """
     s = BytesIO()
-    f = GzipFile(fileobj=s, mode='wb', mtime=0)
+    f = GzipFile(fileobj=s, mode="wb", mtime=0)
     f.write(data)
     f.close()
     return s.getvalue()
@@ -18,4 +17,4 @@ def compress(data, compresslevel=9):
 def decompress(data):
     """ Decompress data in one shot.
     """
-    return GzipFile(fileobj=BytesIO(data), mode='rb').read()
+    return GzipFile(fileobj=BytesIO(data), mode="rb").read()
